[Bug 1027432] [NEW] patch rejected during unpack
Dave Gilbert
ubuntu at treblig.org
Sat Jul 21 16:03:14 UTC 2012
Public bug reported:
It looks like there is a bad patch in the source package, or at least a
disagreement with the tar; it's leaving a .rej :
apt-get source binutils-multiarch
Reading package lists... Done
Building dependency tree
Reading state information... Done
Picking 'binutils' as source package instead of 'binutils-multiarch'
NOTICE: 'binutils' packaging is maintained in the 'Bzr' version control system at:
http://bazaar.launchpad.net/~ubuntu-core-dev/binutils/pkg-ubuntu
Please use:
bzr branch http://bazaar.launchpad.net/~ubuntu-core-dev/binutils/pkg-ubuntu
to retrieve the latest (possibly unreleased) updates to the package.
Need to get 25.3 MB of source archives.
Get:1 http://gb.archive.ubuntu.com/ubuntu/ quantal/main binutils 2.22.52.20120713-0ubuntu1 (dsc) [2,030 B]
Get:2 http://gb.archive.ubuntu.com/ubuntu/ quantal/main binutils 2.22.52.20120713-0ubuntu1 (tar) [25.2 MB]
Get:3 http://gb.archive.ubuntu.com/ubuntu/ quantal/main binutils 2.22.52.20120713-0ubuntu1 (diff) [142 kB]
Fetched 25.3 MB in 21s (1,179 kB/s)
gpgv: Signature made Sat 14 Jul 2012 00:12:13 BST using DSA key ID 0F932C9C
gpgv: Can't check signature: public key not found
dpkg-source: warning: failed to verify signature on ./binutils_2.22.52.20120713-0ubuntu1.dsc
dpkg-source: info: extracting binutils in binutils-2.22.52.20120713
dpkg-source: info: unpacking binutils_2.22.52.20120713.orig.tar.gz
dpkg-source: info: applying binutils_2.22.52.20120713-0ubuntu1.diff.gz
dpkg-source: info: upstream files that have been modified:
binutils-2.22.52.20120713/bfd/elflink.c.rej
0996c2390e583003d6c9c1ffd569b799 binutils_2.22.52.20120713-0ubuntu1.diff.gz
1228fd7b4ab6d93b3ae57c2843c2671c binutils_2.22.52.20120713-0ubuntu1.dsc
7c9ff266ba91db1cef03fdd8a1c8f4b9 binutils_2.22.52.20120713.orig.tar.gz
more binutils-2.22.52.20120713/bfd/elflink.c.rej
--- bfd/elflink.c
+++ bfd/elflink.c
@@ -4712,6 +4712,7 @@
asection *slook;
bfd_vma vlook;
long ilook;
+ int tlook;
size_t i, j, idx;
hlook = weaks;
@@ -4762,9 +4764,10 @@
{
h = sorted_sym_hash [i];
/* Stop if value or section doesn't match. */
if (h->root.u.def.value != vlook
- || h->root.u.def.section != slook)
+ || h->root.u.def.section != slook
+ || h->type != tlook)
break;
else if (h != hlook)
{
@@ -4762,9 +4764,10 @@
{
h = sorted_sym_hash [i];
- /* Stop if value or section doesn't match. */
+ /* Stop if value, section or type doesn't match. */
if (h->root.u.def.value != vlook
ProblemType: Bug
DistroRelease: Ubuntu 12.10
Package: binutils-multiarch 2.22.52.20120713-0ubuntu1
ProcVersionSignature: Ubuntu 3.5.0-5.5-generic 3.5.0-rc7
Uname: Linux 3.5.0-5-generic x86_64
ApportVersion: 2.4-0ubuntu4
Architecture: amd64
Date: Sat Jul 21 16:58:00 2012
InstallationMedia: Kubuntu 12.10 "Quantal Quetzal" - Alpha amd64 (20120717)
ProcEnviron:
LANGUAGE=en_GB:en
TERM=xterm
PATH=(custom, no user)
LANG=en_GB.UTF-8
SHELL=/bin/bash
SourcePackage: binutils
UpgradeStatus: No upgrade log present (probably fresh install)
** Affects: binutils (Ubuntu)
Importance: Undecided
Status: New
** Tags: amd64 apport-bug quantal
--
You received this bug notification because you are a member of Ubuntu
Foundations Bugs, which is subscribed to binutils in Ubuntu.
https://bugs.launchpad.net/bugs/1027432
Title:
patch rejected during unpack
Status in “binutils” package in Ubuntu:
New
Bug description:
It looks like there is a bad patch in the source package, or at least
a disagreement with the tar; it's leaving a .rej :
apt-get source binutils-multiarch
Reading package lists... Done
Building dependency tree
Reading state information... Done
Picking 'binutils' as source package instead of 'binutils-multiarch'
NOTICE: 'binutils' packaging is maintained in the 'Bzr' version control system at:
http://bazaar.launchpad.net/~ubuntu-core-dev/binutils/pkg-ubuntu
Please use:
bzr branch http://bazaar.launchpad.net/~ubuntu-core-dev/binutils/pkg-ubuntu
to retrieve the latest (possibly unreleased) updates to the package.
Need to get 25.3 MB of source archives.
Get:1 http://gb.archive.ubuntu.com/ubuntu/ quantal/main binutils 2.22.52.20120713-0ubuntu1 (dsc) [2,030 B]
Get:2 http://gb.archive.ubuntu.com/ubuntu/ quantal/main binutils 2.22.52.20120713-0ubuntu1 (tar) [25.2 MB]
Get:3 http://gb.archive.ubuntu.com/ubuntu/ quantal/main binutils 2.22.52.20120713-0ubuntu1 (diff) [142 kB]
Fetched 25.3 MB in 21s (1,179 kB/s)
gpgv: Signature made Sat 14 Jul 2012 00:12:13 BST using DSA key ID 0F932C9C
gpgv: Can't check signature: public key not found
dpkg-source: warning: failed to verify signature on ./binutils_2.22.52.20120713-0ubuntu1.dsc
dpkg-source: info: extracting binutils in binutils-2.22.52.20120713
dpkg-source: info: unpacking binutils_2.22.52.20120713.orig.tar.gz
dpkg-source: info: applying binutils_2.22.52.20120713-0ubuntu1.diff.gz
dpkg-source: info: upstream files that have been modified:
binutils-2.22.52.20120713/bfd/elflink.c.rej
0996c2390e583003d6c9c1ffd569b799 binutils_2.22.52.20120713-0ubuntu1.diff.gz
1228fd7b4ab6d93b3ae57c2843c2671c binutils_2.22.52.20120713-0ubuntu1.dsc
7c9ff266ba91db1cef03fdd8a1c8f4b9 binutils_2.22.52.20120713.orig.tar.gz
more binutils-2.22.52.20120713/bfd/elflink.c.rej
--- bfd/elflink.c
+++ bfd/elflink.c
@@ -4712,6 +4712,7 @@
asection *slook;
bfd_vma vlook;
long ilook;
+ int tlook;
size_t i, j, idx;
hlook = weaks;
@@ -4762,9 +4764,10 @@
{
h = sorted_sym_hash [i];
/* Stop if value or section doesn't match. */
if (h->root.u.def.value != vlook
- || h->root.u.def.section != slook)
+ || h->root.u.def.section != slook
+ || h->type != tlook)
break;
else if (h != hlook)
{
@@ -4762,9 +4764,10 @@
{
h = sorted_sym_hash [i];
- /* Stop if value or section doesn't match. */
+ /* Stop if value, section or type doesn't match. */
if (h->root.u.def.value != vlook
ProblemType: Bug
DistroRelease: Ubuntu 12.10
Package: binutils-multiarch 2.22.52.20120713-0ubuntu1
ProcVersionSignature: Ubuntu 3.5.0-5.5-generic 3.5.0-rc7
Uname: Linux 3.5.0-5-generic x86_64
ApportVersion: 2.4-0ubuntu4
Architecture: amd64
Date: Sat Jul 21 16:58:00 2012
InstallationMedia: Kubuntu 12.10 "Quantal Quetzal" - Alpha amd64 (20120717)
ProcEnviron:
LANGUAGE=en_GB:en
TERM=xterm
PATH=(custom, no user)
LANG=en_GB.UTF-8
SHELL=/bin/bash
SourcePackage: binutils
UpgradeStatus: No upgrade log present (probably fresh install)
To manage notifications about this bug go to:
https://bugs.launchpad.net/ubuntu/+source/binutils/+bug/1027432/+subscriptions
More information about the foundations-bugs
mailing list